==> krystex-9.0.0-20250421.065804-7.jar: module-info.java <==
module flipkart.krystal.krystex {
    requires com.google.common;
    requires org.checkerframework.checker.qual;
    /* static phase */ requires io.github.resilience4j.all;
    /* static phase */ requires io.github.resilience4j.bulkhead;
    /* static phase */ requires io.github.resilience4j.circuitbreaker;
    /* static phase */ requires lombok;
    /* static phase */ requires org.slf4j;
    requires flipkart.krystal.common;
    requires com.fasterxml.jackson.databind;
    requires com.fasterxml.jackson.datatype.jsr310;
    requires com.fasterxml.jackson.datatype.jdk8;

    exports com.flipkart.krystal.krystex to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.kryon to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.logicdecoration to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.logicdecorators.resilience4j to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.logicdecorators.observability to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.request to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.resolution to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.commands to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.kryondecoration;
    exports com.flipkart.krystal.krystex.caching;
    exports com.flipkart.krystal.krystex.dependencydecoration;
    exports com.flipkart.krystal.krystex.dependencydecorators;

}

==> krystex-9.7.1.jar: module-info.java <==
module flipkart.krystal.krystex {
    requires com.google.common;
    requires org.checkerframework.checker.qual;
    /* static phase */ requires io.github.resilience4j.all;
    /* static phase */ requires io.github.resilience4j.bulkhead;
    /* static phase */ requires io.github.resilience4j.circuitbreaker;
    /* static phase */ requires lombok;
    /* static phase */ requires org.slf4j;
    requires flipkart.krystal.common;
    requires com.fasterxml.jackson.databind;
    requires com.fasterxml.jackson.datatype.jsr310;
    requires com.fasterxml.jackson.datatype.jdk8;

    exports com.flipkart.krystal.krystex to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.logicdecoration to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.logicdecorators.resilience4j to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.logicdecorators.observability to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.request to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.resolution to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.commands to flipkart.krystal.vajramexecutor.krystex;
    exports com.flipkart.krystal.krystex.kryondecoration;
    exports com.flipkart.krystal.krystex.caching;
    exports com.flipkart.krystal.krystex.dependencydecoration;
    exports com.flipkart.krystal.krystex.dependencydecorators;
    exports com.flipkart.krystal.krystex.kryon;
    exports com.flipkart.krystal.krystex.decoration to flipkart.krystal.vajramexecutor.krystex;

}
